@@ -40,7 +40,7 @@ class CleverSession(CleverDict):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        start_gui()
+        start_gui(redirect=kwargs.get("redirect"))
         self.check_and_prompt("url")
         if self.get("url"):
             self.account = CleverSession.choices[self.url]
